"""Test ripefruit.py module

To run use one of these two options:
- Add ripefruit.py parent directory to PYTHONPATH
- Hard code the path to ripefruit.py here
"""
# Add parent directory to PYTHONPATH
# import sys
# import os
# curdir = os.path.dirname(__file__)
# pardir = os.path.dirname(curdir)
# sys.path.insert(0, pardir)

import ripefruit as rf
import json

# Test web pages on disk
# from "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/5_products.html"
URL = "ripe_fruit_test.html"
# from  "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-apricot-ripe---ready-320g.html"
PRODUCT_URL1 = "apricots.html"
PRODUCT_URL2 = "avocados-loose.html"

def test_get_product_urls(url=URL):
    """Test the function for getting the product urls from the input
    page
    """
    urls = list(rf.get_product_urls(url))
    for url in [PRODUCT_URL1, PRODUCT_URL2]:
        assert url in urls

def test_process_url1(url=PRODUCT_URL1):
    """Test the function that returns a python dict for each product
    url.
    """
    data = {}
    data['title'] = "Sainsbury's Apricot Ripe & Ready x5"
    data['unit_price'] = 3.50
    data['size'] = "39.2kb"  # using 1kb = 1000 bytes
    data['description'] = "Apricots"
    assert data == rf.process_url(url)

def test_process_url2(url=PRODUCT_URL2):
    data = {}
    data['title'] = "Sainsbury's Avocado Ripe & Ready XL Loose 300g"
    data['unit_price'] = 1.50
    data['size'] = "39.6kb"  # using 1kb = 1000 bytes
    data['description'] = "Avocados"
    assert data == rf.process_url(url)

def test_tojson():
    results = [
        {
            "title":"Sainsbury's Avocado, Ripe & Ready x2",
            "size": "90.6kb",
            "unit_price": 1.80,
            "description": "Great to eat now - refrigerate at home 1 of 5 a day 1 avocado counts as 1 of your 5..."
         },
        {
            "title":"Sainsbury's Avocado, Ripe & Ready x4",
            "size": "87kb",
            "unit_price": 2.00,
            "description": "Great to eat now - refrigerate at home 1 of 5 a day 1..."
        }
        ]
    # exact = dict(results=results, total=3.8)
    # j1 = json.dumps(exact,
    #                 sort_keys=True,
    #                 indent=4,
    #                 separators=(',', ': '))
    j1 = """{
    "results": [
        {
            "description": "Great to eat now - refrigerate at home 1 of 5 a day 1 avocado counts as 1 of your 5...",
            "size": "90.6kb",
            "title": "Sainsbury's Avocado, Ripe & Ready x2",
            "unit_price": 1.8
        },
        {
            "description": "Great to eat now - refrigerate at home 1 of 5 a day 1...",
            "size": "87kb",
            "title": "Sainsbury's Avocado, Ripe & Ready x4",
            "unit_price": 2.0
        }
    ],
    "total": 3.8
}"""
    j2 = rf.tojson(results)
    assert j1 == j2

def test_scrape(url=URL):
    j = rf.scrape(url)
    d = json.loads(j)
    assert 'results' in d
    assert 'total' in d
    for product in d['results']:
        assert 'description' in product and isinstance(product['description'], unicode)
        assert 'title' in product and isinstance(product['title'], unicode)
        assert 'unit_price' in product and isinstance(product['unit_price'], float)
        assert 'size' in product and isinstance(product['size'], unicode)

### Old tests: require network access
# Test website
# DEV_URL = "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/5_products.html"
# def test_get_product_urls(url=DEV_URL):
#     urls = list(rf.get_product_urls(url))
#     for url in \
#         ["http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-apricot-ripe---ready-320g.html",
#          "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-avocado-xl-pinkerton-loose-300g.html",
#          "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-avocado--ripe---ready-x2.html",
#          "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-avocados--ripe---ready-x4.html",
#          "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-conference-pears--ripe---ready-x4-%28minimum%29.html",
#          "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-golden-kiwi--taste-the-difference-x4-685641-p-44.html",
#          "http://hiring-tests.s3-website-eu-west-1.amazonaws.com/2015_Developer_Scrape/sainsburys-kiwi-fruit--ripe---ready-x4.html"]:
#         assert url in urls
